Range-v3: meta::bind_back< F, Us > Struct Template Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Types | List of all members
meta::bind_back< F, Us > Struct Template Reference
Meta » Trait » Composition

## Description

### template<typename F, typename... Us>
struct meta::bind_back< F, Us >

A Callable that partially applies the Callable `F` by binding the arguments `Us` to the back of `F`.

## Public Types
template<typename... Ts>
using | invoke = invoke< F, Ts..., Us... >